@@ -42,8 +42,8 @@ class AGDA(nn.Module):
         self.sigma = sigma
         self.noise_rate = noise_rate
         self.scale_factor = scale_factor
-        self.threshold = threshold
-        self.zoom = zoom
+        self.threshold = tuple(threshold)
+        self.zoom = tuple(zoom)
         self.mode = mode
         self.filter = kornia.filters.GaussianBlur2d(
             (self.kernel_size, self.kernel_size), (self.sigma, self.sigma)
@@ -361,7 +361,7 @@ class MAT(nn.Module):
         net = model_config['NET']  #'xception',
         feature_layer = model_config['FEATURE_LAYER']  #'b3',
         attention_layer = model_config['ATTENTION_LAYER']  #'final',
-        num_classes = 2,
+        num_classes = 2
         num_attentions = model_config['NUM_ATTENTIONS']  # 8,
         mid_dims = model_config['MID_DIMS']  # 256,
         dropout_rate = model_config['DROPOUT_RATE']  # 0.5,
@@ -379,7 +379,6 @@ class MAT(nn.Module):
         self.attention_layer = attention_layer
         with torch.no_grad():
             layers = self.net({'img': torch.zeros(1, 3, size[0], size[1])})
-            print(layers)
         num_features = layers[self.feature_layer].shape[1]
         self.mid_dims = mid_dims
         self.attentions = AttentionMap(
@@ -395,6 +394,7 @@ class MAT(nn.Module):
             nn.Linear(mid_dims, mid_dims),
         )
         self.project_final = nn.Linear(layers['final'].shape[1], mid_dims)
+        # print(mid_dims,num_classes)
         self.ensemble_classifier_fc = nn.Sequential(
             nn.Linear(mid_dims * 2, mid_dims),
             nn.Hardswish(),
@@ -415,11 +415,14 @@ class MAT(nn.Module):
         self.dropout = nn.Dropout2d(dropout_rate, inplace=True)
         self.dropout_final = nn.Dropout(drop_final_rate, inplace=True)
 
-        self.AG = AGDA(model_config['AGDA_CONFIG'])
+        if model_config['AGDA_CONFIG']['AGDA_LOSS_WEIGHT'] != 0:
+            self.AG = AGDA(model_config['AGDA_CONFIG'])
+        else:
+            self.AG = None
 
     def train_batch(self, x, y, drop_final=False):
         y = torch.squeeze(y).long()
-        layers = self.net(x)
+        layers = self.net({'img': x})
         if self.feature_layer == 'logits':
             logits = layers['logits']
             loss = F.cross_entropy(logits, y)
@@ -472,7 +475,7 @@ class MAT(nn.Module):
         x = samples['img']
         y = samples['bin_label']
         if self.training:
-            if self.AG.AGDA_loss_weight == 0:
+            if self.AG is None:
                 return self.train_batch(x, y)
             else:
                 loss_pack = self.train_batch(x, y)
@@ -491,10 +494,10 @@ class MAT(nn.Module):
                     * (torch.ones_like(one_hot) - one_hot)
                 )
                 return loss_pack
-        layers = self.net(x)
+        layers = self.net({'img': x})
         if self.feature_layer == 'logits':
-            logits = layers['logits']
-            return logits
+            layers.update({'loss': torch.tensor(0.)})
+            return layers
         raw_attentions = layers[self.attention_layer]
         attention_maps = self.attentions(raw_attentions)
         feature_maps = layers[self.feature_layer]
@@ -512,4 +515,4 @@ class MAT(nn.Module):
         projected_final = F.hardswish(self.project_final(final))
         feature_matrix = torch.cat((feature_matrix, projected_final), 1)
         ensemble_logit = self.ensemble_classifier_fc(feature_matrix)
-        return ensemble_logit
+        return dict(logits = ensemble_logit, loss = torch.tensor(0.))
